@@ -1,7 +1,7 @@
 package MIME::Detect::FreeDesktopOrgDB;
 use strict;
-use vars '$VERSION';
-$VERSION = '0.09';
+use File::ShareDir 'dist_file';
+our $VERSION = '0.10';
 
 =head1 NAME
 
@@ -31,7 +31,7 @@ with this module.
 =cut
 
 sub get_xml {
-    (my $xml_name = __FILE__) =~ s!\.pm$!/mime-info/freedesktop.org.xml!;
+    (my $xml_name = dist_file('MIME-Detect', 'mime-info/freedesktop.org.xml'));
     open my $fh, '<', $xml_name
         or die "Couldn't read '$xml_name': $!";
     binmode $fh;
@@ -44,7 +44,7 @@ sub get_xml {
 =head1 REPOSITORY
 
 The public repository of this module is 
-L<http://github.com/Corion/filter-signatures>.
+L<http://github.com/Corion/mime-detect>.
 
 =head1 SUPPORT
 
@@ -54,7 +54,7 @@ L<https://perlmonks.org/>.
 =head1 BUG TRACKER
 
 Please report bugs in this module via the RT CPAN bug queue at
-L<https://rt.cpan.org/Public/Dist/Display.html?Name=Filter-signatures>
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=MIME-Detect>
 or via mail to L<filter-signatures-Bugs@rt.cpan.org>.
 
 =head1 AUTHOR
@@ -63,7 +63,7 @@ Max Maischein C<corion@cpan.org>
 
 =head1 COPYRIGHT (c)
 
-Copyright 2015-2016 by Max Maischein C<corion@cpan.org>.
+Copyright 2015-2018 by Max Maischein C<corion@cpan.org>.
 
 =head1 LICENSE
 
